@@ -10,8 +10,8 @@
   # d = 149597870700 * (1 - 0.01672 * cos(deg2rad(0.9856 * (day - 4))))
 
   # To radians
-  az_rad = .deg2rad(90 - sun_az)
-  sun_elev = .deg2rad(sun_elev)
+  az_rad = deg2rad(90 - sun_az)
+  sun_elev = deg2rad(sun_elev)
 
   # Sun height
   height = data.frame(height = dist_m * tan(sun_elev))
